
#ifndef VTEX_COMMON_ERRORS_H
#define VTEX_COMMON_ERRORS_H

enum {
#ifndef _CommonErrors_H
    //! SUCCESS CODE, DO NOT CHANGE
    IVI_SUCCESS = 0,

    //! Specific Driver Exception error.
    //! This is a single error which indicates at the COM/lib layer that a driver/firmware error occurred.
    //! DO NOT EDIT the below error code.
    IVI_E_SPECIFIC_DRIVER_EXCEPTION = 0x800440ff,

    //! IVI errors.
    IVI_E_BASE = 0x80047000,

    IVI_E_CANNOT_RECOVER = 0x80047000,
    IVI_E_INSTRUMENT_STATUS = 0x80047001,
    IVI_E_CANNOT_OPEN_FILE = 0x80047002,
    IVI_E_READING_FILE = 0x80047003,
    IVI_E_WRITING_FILE = 0x80047004,
    IVI_E_INVALID_PATHNAME = 0x8004700b,
    IVI_E_INVALID_VALUE = 0x80047010,
    //! FUNCTION and METHOD are the same code
    IVI_E_FUNCTION_NOT_SUPPORTED = 0x80047011,
    IVI_E_METHOD_NOT_SUPPORTED = 0x80047011,
    //! PROPERTY and ATTRIBUTE are the same code
    IVI_E_ATTRIBUTE_NOT_SUPPORTED = 0x80047012,
    IVI_E_PROPERTY_NOT_SUPPORTED = 0x80047012,
    IVI_E_VALUE_NOT_SUPPORTED = 0x80047013,
    IVI_E_NOT_INITIALIZED = 0x8004701d,
    IVI_E_UNKNOWN_CHANNEL_NAME = 0x80047020,
    IVI_E_TOO_MANY_OPEN_FILES = 0x80047023,
    IVI_E_CHANNEL_NAME_REQUIRED = 0x80047044,
    IVI_E_MISSING_OPTION_NAME = 0x80047049,
    IVI_E_MISSING_OPTION_VALUE = 0x8004704a,
    IVI_E_BAD_OPTION_NAME = 0x8004704b,
    IVI_E_BAD_OPTION_VALUE = 0x8004704c,
    IVI_E_OUT_OF_MEMORY = 0x80047056,
    IVI_E_OPERATION_PENDING = 0x80047057,
    IVI_E_NULL_POINTER = 0x80047058,
    IVI_E_UNEXPECTED_RESPONSE = 0x80047059,
    IVI_E_FILE_NOT_FOUND = 0x8004705b,
    IVI_E_INVALID_FILE_FORMAT = 0x8004705c,
    IVI_E_STATUS_NOT_AVAILABLE = 0x8004705d,
    IVI_E_ID_QUERY_FAILED = 0x8004705e,
    IVI_E_RESET_FAILED = 0x8004705f,
    IVI_E_RESOURCE_UNKNOWN = 0x80047060,
    IVI_E_ALREADY_INITIALIZED = 0x80047061,
    IVI_E_CANNOT_CHANGE_SIMULATION_STATE = 0x80047062,
    IVI_E_INVALID_NUMBER_OF_LEVELS_IN_SELECTOR = 0x80047063,
    IVI_E_INVALID_RANGE_IN_SELECTOR = 0x80047064,
    IVI_E_UNKOWN_NAME_IN_SELECTOR = 0x80047065,
    IVI_E_UNKNOWN_NAME_IN_SELECTOR = 0x80047065,
    IVI_E_BADLY_FORMED_SELECTOR = 0x80047066,
    IVI_E_UNKNOWN_PHYSICAL_IDENTIFIER = 0x80047067,

    //! IVI Warnings
    IVI_W_BASE = 0x47000,

    IVI_W_NSUP_ID_QUERY = 0x47065,
    IVI_W_NSUP_RESET = 0x47066,
    IVI_W_NSUP_SELF_TEST = 0x47067,
    IVI_W_NSUP_ERROR_QUERY = 0x47068,
    IVI_W_NSUP_REV_QUERY = 0x47069,

    // These were required to be brought over from CommonErrors.h for consistency with EX1200
    // See notes below about the values
    VTEX_E_VIRTUAL_INSTRUMENT_NOT_CONSISTENT = 0x80044050,
    VTEX_E_NO_MODULES_INITIALIZED = 0x80044051,
    VTEX_E_LOG_FILE_ALREADY_OPEN = 0x80044052, 
    VTEX_E_INVALID_LOG_FILE_ACCESS_MODE = 0x80044053,
    VTEX_E_SPECIFIED_MODULE_DOES_NOT_EXIST_AT_SPECIFIED_SLOT = 0x80044054,
#endif //_CommonErrors_H for the EX1200 errors

    // Errors below this line are specific to SentinelEX (CMX/EMX/SMX)
    // Note, IVI gives us only the 0x80044xxx range to describe errors
    // VTEX common errors are between 0x80044000 and 0x800440ff
    // VTEX driver specific errors are between 0x80044100 and 0x80044fff
    VTEX_E_ERROR_BASE = 0x80044000,
    VTEX_E_INTERNAL  = 0x80044000,
    VTEX_E_NET_ERROR = 0x80044001,
    VTEX_E_REPEATED_CAPABILITY_IDENTIFIER_EXISTS = 0x80044002,
    VTEX_E_TIMEOUT = 0x80044003,
    VTEX_E_UPGRADE_FAILED = 0x80044004,
    VTEX_E_ERROR_QUEUE_EMPTY = 0x80044005,
    VTEX_E_MAX_SIZE_EXCEEDED = 0x80044006,
    VTEX_E_INCONSISTENT_FILE_STATE = 0x80044007,
    VTEX_E_FLASH = 0x80044008,
    VTEX_E_OPERATION_INVALID_WHILE_CALIBRATION_RUNNING = 0x80044009,
    VTEX_E_OPERATION_INVALID_WHILE_TRIGGER_MODEL_NOT_IDLE = 0x8004400a,
    VTEX_E_TEDS = 0x8004400b,
    VTEX_E_START_SOURCE_NOT_SOFTWARE = 0x8004400c,
    VTEX_E_FIFO_OVERFLOW = 0x8004400d,
    VTEX_E_INVALID_VRT_DATA = 0x8004400e,
    VTEX_E_START_REQUIRED = 0x8004400f,
    VTEX_E_ALREADY_STREAMING = 0x80044010,
    VTEX_E_ASYNC_ERROR = 0x80044011,
    VTEX_E_SYNC_SOURCE_NOT_SOFTWARE = 0x80044012,
#ifndef _CommonErrors_H
    VTEX_E_MODEL_NOT_SUPPORTED = 0x80044013, // this error was defined for EX1200, but never used anywhere so it gets a new value in the range IVI gave us
#endif
    VTEX_E_NOT_STREAMING = 0x80044014,
    VTEX_E_INVALID_CALIBRATION = 0x80044015,
    VTEX_E_OPERATION_INVALID_WITH_MULTIPLE_MODULES = 0x80044016,
    VTEX_E_CONFIGURATION_CONFLICT = 0x80044017,
    VTEX_E_CONFIGURATION_BEYOND_INSTRUMENT_CAPABILITIES = 0x80044018,
    VTEX_E_SYNCHRONIZATION_ERROR = 0x80044019,
    VTEX_E_FILE_WRITE = 0x8004401a,
    VTEX_E_DATA_READER_DISABLED = 0x8004401b,

#ifndef _CommonErrors_H
    // Nimbus-defined error codes - these are unused, but defined for all of the IVI drivers
    VTEX_E_IO_GENERAL = 0x800440fd,
    VTEX_E_IO_TIMEOUT = 0x800440fe,
#endif

    // Note, IVI gives us only the 0x00044xxx range to describe warnings.
#ifndef _CommonErrors_H
    VTEX_W_BASE = 0x00044000,
#endif
    VTEX_W_FIFO_OVERFLOW = 0x00044000,
    VTEX_W_NEWER_REVISION_DETECTED = 0x00044001,
    VTEX_W_PCIE_NOT_AVAILABLE = 0x00044002,
    VTEX_W_READ_TIMEOUT = 0x00044003,
};

/*
 * Error Code Base Declarations
 *
 * Each new base should add 0x0100
 */
#define VTEX_E_DIGITIZER_BASE 0x80044100
#define VTEX_E_DSA_BASE 0x80044200
#define VTEX_E_PLATFORM_BASE 0x80044300
#define VTEX_E_SWITCH_BASE 0x80044400

#endif // VTEX_COMMON_ERRORS_H

