/******************************************************************************
 *
 *  .----------------------.    
 *  |==     ==  ======  == |    $Author: bjones $
 *  | ==   ==   ======  == |    $Revision: 41349 $ 
 *  |  == ==      ==    == |    $Date: 2019-02-19 12:54:51 -0800 (Tue, 19 Feb 2019) $ 
 *  |   ===       ==    == |    $HeadURL: http://orion/svn/spiderman/branches/v1_13_14_and_higher/host/driver/lib/common/vtexProperty.h $
 *  |    =        ==    == |    
 *  `----------------------'
 *
 * Copyright 2006 VXI Technology Inc. as an unpublished work. 
 * All rights reserved. The information contained herein is confidential
 * property of VXI Technology, Inc. Use, copy, transfer or disclosure
 * of such information is prohibited except by express written agreement 
 * with VXI Technology, Inc.
 *
 * PURPOSE: 
 *   Template class for various IVI properties
 *
 * First Written By: David Sigler On Jan-2007
 ******************************************************************************/

#ifndef _VTEXPROPERTY_TEMPLATE_
#define _VTEXPROPERTY_TEMPLATE_

#define READ_ONLY   1
#define WRITE_ONLY  2
#define READ_WRITE  3

#include "vtexInherent.h"

template<typename ValueType>
class VTEX_EXPORT vtexPropertyArg
{
    vtexPropertyArg() {};
public:
    typedef ValueType Type;
};

template<typename Container, typename ValueType, int access>
class VTEX_EXPORT vtexProperty
{
public:
    typedef ValueType value_type;

    vtexProperty()
    {
        m_container = NULL;
        m_get = NULL;
        m_set = NULL;
    }

    void SetAttributes(Container *container,
        VTEXResult (Container::*get)(ValueType &value) = NULL,
        VTEXResult (Container::*set)(typename vtexPropertyArg<ValueType>::Type value) = NULL)
    {
        m_container = container;
        m_get = get;
        m_set = set;
    }

    operator ValueType()
    {
        ValueType value;

        (m_container->*m_get)(value);

        return value;
    }

    const ValueType &operator =(const ValueType &value)
    {
        (m_container->*m_set)(value);

        return value;
    }

private:
    Container *m_container;
    VTEXResult (Container::*m_get)(ValueType &value);
    VTEXResult (Container::*m_set)(typename vtexPropertyArg<ValueType>::Type value);
};

#endif //_VTEXPROPERTY_TEMPLATE_

